#!/bin/sh -e

# called by uscan with '--upstream-version' <version> <file>
DIR=code_saturne-$2
DIRTARGET=code-saturne-$2
TAR=../code-saturne_$2.orig.tar.bz2

# clean up the upstream tarball
unzip $3
mv $DIR $DIRTARGET
tar -c -j -f $TAR $DIRTARGET
rm -rf $DIRTARGET $3

# move to directory 'tarballs'
if [ -r .svn/deb-layout ]; then
    . .svn/deb-layout
    mv $TAR $origDir
    echo "moved $TAR to $origDir"
fi

exit 0
